pitchtools.transpose_pitch_carrier_by_melodic_interval
======================================================

.. autofunction:: abjad.tools.pitchtools.transpose_pitch_carrier_by_melodic_interval.transpose_pitch_carrier_by_melodic_interval
